# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16


"""
吉尔吉斯语
"""

ACCURATE_REGEX_LIST = [
    r"(?P<bH>\d+)\s*саат мурда",
]

SUB_TRANSLATE = [

]
FUZZY_REGEX_LIST = []


# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16

"""
俄语
"""

ACCURATE_REGEX_LIST = [
    r"(?P<bS>\d+)\s*секунда?\s*",
    r"(?P<bM>\d+)\s*минута?\s*",
    r"(?P<bH>\d+)\s*час?\s*",
]

SUB_TRANSLATE = [
    (r"январь", "1月"),
    (r"февраль", "2月"),
    (r"март", "3月"),
    (r"апрель|апреля|апрел", "4月"),
    (r"май", "5月"),
    (r"июнь|июня", "6月"),
    (r"июль|июля", "7月"),
    (r"август", "8月"),
    (r"сентябрь", "9月"),
    (r"октябрь", "10月"),
    (r"ноябрь", "11月"),
    (r"декабрь", "12月"),
    (r"сегодня  в|сегодня", "今天"),
    (r"вчера  в|вчера", "昨天"),
]
FUZZY_REGEX_LIST = []


# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16

"""
土耳其语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
    (r"Nisan ", "4月"),
    (r"önce", "前"),
]

FUZZY_REGEX_LIST = [
    r"(?P<bM>\d+)\s*дақиқалар\s*аввал",
]



# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16


"""
德语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
    (r"Januar|Jan", "1月"),
    (r"Februar|Feb\.", "2月"),
    (r"März|Mär", "3月"),
    (r"April|Apr", "4月"),
    (r"Abriil|Abr", "4月"),
    (r"Mai|mai", "5月"),
    (r"Juni|Jun", "6月"),
    (r"Juli|Jnl", "7月"),
    (r"August|Aug", "8月"),
    (r"September|Sep\.", "9月"),
    (r"Oktober|Okt", "10月"),
    (r"November|Nov", "11月"),
    (r"Dezember|Dez", "12月"),
    (r"Uhr", "am"),
    (r"une heure", "1 heure"),
    (r"il y a heure", "il y a 1 heure"),
]
FUZZY_REGEX_LIST = []


# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16


"""
马拉地语
"""

ACCURATE_REGEX_LIST = [
    r"(?P<bM>\d+)\s*तासांपूर्वी",
    r"(?P<bM>\d+)\s*मिनिटांपूर्व",
]

SUB_TRANSLATE = [
    (r'एप्रिल', '4月')
]
FUZZY_REGEX_LIST = []


# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16


"""
印尼语
"""

ACCURATE_REGEX_LIST = [

]

SUB_TRANSLATE = [

]
FUZZY_REGEX_LIST = [
    r"(?P<bM>\d+)\s*jam\s*yang\s*lalu",
]


# -*- coding:utf-8 -*-
# author: kusen
# email: 1194542196@qq.com
# date: 2023/5/16

"""
斯瓦希里语
"""

ACCURATE_REGEX_LIST = [
]

SUB_TRANSLATE = [
]

FUZZY_REGEX_LIST = [
    r"Saa\s*(?P<bH>\d+)\s*zilizopita\s*",
    r"Saa\s*(?P<bH>\d+)\s*iliyopita\s*",
    r"Dakika\s*(?P<bM>\d+)\s*zilizopita\s*",
]
